@@ -15,7 +15,7 @@ slackget10::Network::Connection::HTTP - This class encapsulate LWP::Simple
 
 =head1 VERSION
 
-Version 1.0.0
+Version 0.9.3
 
 =cut
 
@@ -113,12 +113,12 @@ Download and store a given file.
 
 This method return a slackget10::Status object with the following object declaration :
 
-	my $status =  slackget10::Status->new(codes => {
-		0 => "All goes well. Server said:\n\t$ret_code - ".status_message( $ret_code )."\n",
-		1 => "Server error, you must choose the next host for this server. Server said:\n\t$ret_code - ".status_message( $ret_code )."\n",
-		2 => "Client error, it seems that you have a problem with you connection or with the slackget10 library (or with a library which we depended on). Server said:\n\t$ret_code - ".status_message( $ret_code )."\n",
-		3 => "Server has redirected us, we prefer direct connection, change host for this server. Server said:\n\t$ret_code - ".status_message( $ret_code )."\n",
-		4 => "The HTTP connection is not a success and we are not able to know what, we recommend to change the current host of this server. Server said:\n\t$ret_code - ".status_message( $ret_code )."\n"
+	my $state =  slackget10::Status->new(codes => {
+		0 => "All goes well.<br> Server said: <br>$ret_code - ".status_message( $ret_code ),
+		1 => "Server error, you must choose the next host for this server.<br> Server said: $ret_code - $tmp_status_message",
+		2 => "Client error, it seems that you have a problem with you connection or with the slackget10 library <br>(or with a library which we depended on). It is also possible that the file we try to download was not on the remote server.<br> Server said: <br>$ret_code - $tmp_status_message",
+		3 => "Server has redirected us, we prefer direct connection, change host for this server.<br> Server said: <br>$ret_code - $tmp_status_message",
+		4 => "The HTTP connection is not a success and we are not able to know what, we recommend to change the current host of this server.<br> Server said: <br>$ret_code - $tmp_status_message"
 	});
 
 This is the direct code of this method :)
@@ -140,14 +140,16 @@ sub fetch_file {
 	}
 	my $url = $self->protocol().'://'.$self->host().'/'.$self->path().'/'.$remote_file;
 	$url = $self->strip_slash($url);
-# 	print "[debug http] save the fetched file ($url) to $local_file\n";
+#  	print "\n[debug http] save the fetched file ($url) to $local_file\n";
 	my $ret_code = getstore($url,$local_file) ;
+	my $tmp_status_message = status_message( $ret_code );
+	$tmp_status_message=~ s/\n/<br>/g;
 	my $state =  slackget10::Status->new(codes => {
-		0 => "All goes well. Server said:\n\t$ret_code - ".status_message( $ret_code )."\n",
-		1 => "Server error, you must choose the next host for this server. Server said:\n\t$ret_code - ".status_message( $ret_code )."\n",
-		2 => "Client error, it seems that you have a problem with you connection or with the slackget10 library (or with a library which we depended on). Server said:\n\t$ret_code - ".status_message( $ret_code )."\n",
-		3 => "Server has redirected us, we prefer direct connection, change host for this server. Server said:\n\t$ret_code - ".status_message( $ret_code )."\n",
-		4 => "The HTTP connection is not a success and we are not able to know what, we recommend to change the current host of this server. Server said:\n\t$ret_code - ".status_message( $ret_code )."\n"
+		0 => "All goes well.<br> Server said: <br>$ret_code - $tmp_status_message",
+		1 => "Server error, you must choose the next host for this server.<br> Server said: <br>$ret_code - $tmp_status_message",
+		2 => "Client error, it seems that you have a problem with you connection or with the slackget10 library <br>(or with a library which we depended on). It is also possible that the file we try to download was not on the remote server.<br> Server said: <br>$ret_code - $tmp_status_message",
+		3 => "Server has redirected us, we prefer direct connection, change host for this server.<br> Server said: <br>$ret_code - $tmp_status_message",
+		4 => "The HTTP connection is not a success and we are not able to know what, we recommend to change the current host of this server.<br> Server said: <br>$ret_code - $tmp_status_message"
 	});
 	if(is_success($ret_code)){
 		$state->current(0);
